#
# spec file for package openttd
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2007-2012 The OpenTTD developers
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           openttd
Version:        1.5.3
Release:        1.1
Summary:        An open source clone of Chris Sawyer's Transport Tycoon Deluxe
License:        GPL-2.0
Group:          Amusements/Games/Strategy/Other
Url:            http://www.openttd.org
Source:         http://binaries.openttd.org/releases/%{version}/%{name}-%{version}-source.tar.xz
Patch0:         openttd-gcc5.patch
BuildRequires:  SDL-devel
BuildRequires:  fontconfig-devel
BuildRequires:  gcc-c++
BuildRequires:  libicu-devel
BuildRequires:  libpng-devel
BuildRequires:  pkgconfig
BuildRequires:  xz
BuildRequires:  zlib-devel
%if 0%{?mdkversion}
BuildRequires:  liblzma-devel
BuildRequires:  liblzo-devel
%else
BuildRequires:  lzo-devel
BuildRequires:  xz-devel
%endif
%if 0%{?suse_version} || 0%{?mdkversion}
BuildRequires:  freetype2-devel
%else
BuildRequires:  freetype-devel
%endif
%if 0%{?suse_version}
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(libtimidity)
BuildRequires:  pkgconfig(libxdg-basedir)
%else
BuildRequires:  desktop-file-utils
BuildRequires:  grfcodec
Requires:       hicolor-icon-theme
%endif
%if 0%{?suse_version} || 0%{?mdkversion}
Recommends:     openttd-openmsx
Recommends:     openttd-opensfx
Recommends:     adobe-sourcehansans-fonts
%endif
Requires:       %{name}-data = %{version}-%{release}
Conflicts:      %{name}-dedicated
Provides:       %{name}-gui = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%define about OpenTTD is a reimplementation of the Microprose game "Transport Tycoon Deluxe" with lots of new features and enhancements. To play the game you need either the original data from the game or install the recommend subackages OpenGFX for free graphics, OpenSFX for free sounds and OpenMSX for free music.

%description
%about

Use package %{name}-dedicated for systems without SDL.

%package dedicated
Summary:        OpenTTD Dedicated Server binary (without SDL)
Group:          Amusements/Games/Strategy/Other

Requires:       %{name}-data = %{version}-%{release}
Conflicts:      %{name}

%description dedicated
%about

This package provides the binary %{name}-dedicated without dependency of SDL.

%package data
Summary:        OpenTTD data
Group:          Amusements/Games/Strategy/Other
%if 0%{?suse_version} > 1110 || 0%{?fedora} || 0%{?mdkversion} || 0%{?rhel_version} >= 600 || 0%{?centos_version} >= 600
BuildArch:      noarch
%endif
%if 0%{?suse_version} || 0%{?mdkversion}
Recommends:     openttd-opengfx >= 0.5.2
%endif

%description data
%about

This package provides the data files needed by %{name} or %{name}-dedicated.

%prep
%setup -qn %{name}-%{version}
%patch0 -p1

# Remove build time references so build-compare can do its work
sed -i "s/__DATE__/\"openSUSE\"/" src/rev.cpp.in
sed -i "s/__TIME__/\"BuildService\"/" src/rev.cpp.in
sed -i "s/!!DATE!!/openSUSE Build Service/" src/rev.cpp.in

%build
# first, we build the dedicated binary and copy it to dedicated/
CFLAGS="$RPM_OPT_FLAGS" CXXFLAGS="$RPM_OPT_FLAGS" \
CFLAGS_BUILD="$RPM_OPT_FLAGS" CXXFLAGS_BUILD="$RPM_OPT_FLAGS" \
./configure \
        --disable-strip \
        --prefix-dir="%{_prefix}" \
        --binary-dir="bin" \
        --data-dir="share/%{name}" \
        --enable-dedicated
make %{?_smp_mflags} bundle BUNDLE_DIR="dedicated" VERBOSE=1

make distclean
# then, we build the common gui version which we install the usual way
CFLAGS="$RPM_OPT_FLAGS" CXXFLAGS="$RPM_OPT_FLAGS" \
CFLAGS_BUILD="$RPM_OPT_FLAGS" CXXFLAGS_BUILD="$RPM_OPT_FLAGS" \
./configure \
        --disable-strip \
        --prefix-dir="%{_prefix}" \
        --binary-name="%{name}" \
        --binary-dir="bin" \
        --data-dir="share/%{name}" \
        --doc-dir="share/doc/%{name}" \
        --menu-name="OpenTTD" \
        --menu-group="Game;StrategyGame;"

make %{?_smp_mflags} VERBOSE=1

%install
# install the dedicated binary
install -D -m0755 dedicated/openttd %{buildroot}%{_bindir}/%{name}-dedicated
# install the gui binary
make install INSTALL_DIR=%{buildroot} VERBOSE=1

%if 0%{?suse_version}
%suse_update_desktop_file -r %{name} Game StrategyGame
%else
%if 0%{?fedora} || 0%{?mdkversion} || 0%{?rhel_version} >= 600 || 0%{?centos_version} >= 600
desktop-file-install --dir=%{buildroot}%{_datadir}/applications \
        --add-category=StrategyGame \
        media/openttd.desktop
%endif
%endif

%post
touch --no-create %{_datadir}/icons/hicolor >/dev/null 2>&1 || :

%post dedicated
rm -f %{_bindir}/%{name}
ln -s %{name}-dedicated %{_bindir}/%{name}

%preun dedicated
if [ "$1" -eq 0 ] ; then
    rm -f %{_bindir}/%{name}
fi

%postun
if [ "$1" -eq 0 ] ; then
    touch --no-create %{_datadir}/icons/hicolor >/dev/null 2>&1
    gtk-update-icon-cache %{_datadir}/icons/hicolor >/dev/null 2>&1 || :
fi

%posttrans
gtk-update-icon-cache %{_datadir}/icons/hicolor >/dev/null 2>&1 || :

%files
%defattr(-, root, root)
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor
%{_datadir}/pixmaps/%{name}.32.xpm
%{_mandir}/man6/%{name}.6.*

%files dedicated
%defattr(-, root, root)
%{_bindir}/%{name}-dedicated

%files data
%defattr(-, root, root)
%{_datadir}/doc/%{name}
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/lang
%{_datadir}/%{name}/baseset
%{_datadir}/%{name}/scripts
%{_datadir}/%{name}/ai
%{_datadir}/%{name}/game

%changelog
* Thu Jun 16 2016 dimstar@opensuse.org
- Update openttd-gcc5.patch: Have gcc6 use the same flags as gcc5.
* Thu Apr  7 2016 bwiedemann@suse.com
- Fix build-compare
* Sat Dec  5 2015 mailaender@opensuse.org
- maintenance update 1.5.3
  * fixes a long standing desync issue with railtypes
* Thu Oct 15 2015 tchvatal@suse.com
- Version bump to 1.5.2:
  * For details see changelog.txt
* Wed Sep 30 2015 lnussel@suse.de
- build with proper optflags
* Fri Jun 19 2015 dimstar@opensuse.org
- Add openttd-gcc5.patch: Fix build with gcc 5.
* Sat Jun  6 2015 mailaender@opensuse.org
- update to version 1.5.1 (check changelog.txt)
* Sun Apr 26 2015 mailaender@opensuse.org
- Removed openttd-freetype-2.5.4.patch (included by upstream)
- Updated to version 1.5.0
  * higher mountains
  * better UI for high resolution screens
  * much more rural intro screen.
- Recommend adobe-sourcehansans-fonts as backfall when there is no
  sprite font (yet). Workaround https://bugs.openttd.org/task/6226
* Mon Dec 22 2014 dimstar@opensuse.org
- Add openttd-freetype-2.5.4.patch: Fix build with freetype 2.5.4.
- Move the man page to the binary, where it belongs (and drop
  the rpmlintrc-, which is now no longer valid).
* Sun Nov  9 2014 Led <ledest@gmail.com>
- fix bashisms in post scripts
* Sun Oct 26 2014 mailaender@opensuse.org
- update to 1.4.4 (check changelog.txt)
* Sun Sep 28 2014 mailaender@opensuse.org
- update to 1.4.3 (bug fix release)
- added missing build requires:
  * libxdg-basedir
  * libtimidity
  * grfcodec
- avoid redundancy in %%description
* Sat Jun 14 2014 mailaender@opensuse.org
- update to 1.4.1 (regular bug fix release)
- use LZMA compressed source
* Fri Apr  4 2014 adrian@suse.de
- update to 1.4.0
  (check changelog.txt)
* Tue Dec 10 2013 suse@ammler.ch
- update to 1.3.3 (security bugfix)
  - many bugfixes including:
    Fix: Aircraft crashing near the map's border due to a lack of airports
    could trigger a crash [CVE-2013-6411] [FS#5820] (bnc#853041)
* Mon Sep 30 2013 suse@ammler.ch
- update to 1.3.2 (bugfix release)
* Sun Jun  2 2013 coder.tux@gmail.com
- update to 1.3.1
* Tue Apr  2 2013 suse@ammler.ch
- update to 1.3.0
  (check changelog.txt)
* Sun Feb 17 2013 suse@ammler.ch
- update to 1.3.0-beta2
  (check changelog.txt)
* Fri Nov  2 2012 suse@ammler.ch
- update to 1.2.3 (bugfix release)
* Thu Aug 16 2012 suse@ammler.ch
- update to 1.2.2
  - many bugfixes including:
    Fix: In some cases ships could be covered with land [FS#5254]
    (CVE-2012-3436, bnc#775023)
* Thu May 31 2012 suse@ammler.ch
- update to 1.2.1
  - many minor bugfixes (see changelog.txt)
* Wed May  9 2012 suse@ammler.ch
- remove BuildRequires hicolor-icon-them (build on SLE_10)
* Fri May  4 2012 suse@ammler.ch
- remove __DATE__ and __TIME__ reference for build-compare
- disable strip so we get debug rpms (also for stable releases)
* Mon Apr 16 2012 suse@ammler.ch
- update to 1.2.0
  * too many changes to list here, please see changelog.txt
    (files data/* moved to baseset/, no gm/ anymore)
* Mon Apr  9 2012 suse@ammler.ch
- remove update-alternatives again (bnc#749128)
- symlink openttd to openttd-dedicated
* Mon Apr  2 2012 suse@ammler.ch
- update to 1.2.0-RC4
* Tue Mar  6 2012 suse@ammler.ch
- upstream update to 1.2.0-RC2
- spec overhaul for openSUSE Factory
* Mon Jan 16 2012 suse@ammler.ch
- upstream update 1.1.5
  * Fix: Make default timeouts for certain network states lower
    and configurable [CVE-2012-0049]
- disable dependency grfcodec
* Tue Dec  6 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
* Tue Dec  6 2011 suse@ammler.ch
- upstream update 1.1.4
  * various small bugfixes
* Sun Sep 18 2011 ammler@openttdcoop.org
- upstream update 1.1.3
  * Add: River graphics for the original base set
* Wed Aug 17 2011 ammler@openttdcoop.org
- upstream update 1.1.2
- no obs services anymore
* Thu Jun  2 2011 ammler@openttdcoop.org
- upstream update 1.1.1
* Fri Apr  1 2011 ammler@openttdcoop.org
- upstream update 1.1.0
  * Change newgrfs settings aren't allowed anymore on running
    game per default, needs scenario_developer to be set
  * Feature: XZ/LZMA2 savegame support. New default reduces
    savegame size by 10 to 30%% with slightly more CPU usage.
    (requires xz-devel)
  * Feature: Remote administration
  * Feature: a lot improvements with GUI
  * Feature: Customizable hotkeys
  * Sources for openttd.grf are pngs (requires grfcodec >= 5.1)
* Sun Nov 21 2010 ammler@openttdcoop.org
- upstream update 1.0.5
  * Fix: Reading (very) recently freed memory [CVE-2010-4168]
* Sun Oct 31 2010 ammler@openttdcoop.org
- upstream update 1.0.4
  * build openttd.grf from source
* Tue Aug 10 2010 ammler@openttdcoop.org
- upstream update 1.0.3
* Wed Jun 23 2010 Marcel Gmür <ammler@openttdcoop.org>
- upstream update 1.0.2
  * Feature: Translated desktop shortcut comments (r19884)
  * many minor Bugfixes
* Sat May  1 2010 Marcel Gmür <ammler@openttdcoop.org>
- upstream update 1.0.1
  * Fix: Leaking a file descriptor
  * Fix a lot small bugs, like minor desync issues on Mulitplayer
- no strip on make
* Thu Apr  1 2010 Marcel Gmür <ammler@openttdcoop.org>
- upstream update 1.0.0 (finally!)
  * completely independend game but still working also
    with ttd original gaphics, sounds and music
- Add: Recommends openmsx
- requires lzo2
* Fri Dec 18 2009 Marcel Gmür <ammler@openttdcoop.org> - 0.7.4
- support for differen branches
- easy support for dedicated branch
- let openttd build system make the dektop file
- split the package to data and gui
- disable requires
* Thu Oct  1 2009 Marcel Gmür <ammler@openttdcoop.org> - 0.7.3
- disable libicu for RHEL4
* Sat Sep 26 2009 Marcel Gmür <ammler@openttdcoop.org> - 0.7.2
- no subfolder games for datadir
- cleanup: no post and postun anymore
- Recommends: opengfx (for suse and mandriva)
- add SUSE support
* Mon Oct 20 2008 Benedikt Brüggemeier <skidd13@openttd.org>
- Added libicu dependency
* Tue Sep 23 2008 Benedikt Brüggemeier <skidd13@openttd.org>
- Merged both versions of the spec file
* Fri Aug 29 2008 Jonathan Coome <maedhros@openttd.org>
- Rewrite spec file from scratch.
* Sat Aug  2 2008 Benedikt Brüggemeier <skidd13@openttd.org>
- Updated spec file
* Thu Mar 27 2008 Denis Burlaka <burlaka@yandex.ru>
- Universal spec file
